@@ -1,6 +1,6 @@
 package Acme::PrettyCure::Girl::Role::Fresh;
 use utf8;
-use Moo::Role;
+use Any::Moose '::Role';
 
 before 'transform' => sub {
     my ($self, @buddies) = @_;
